from setuptools import setup, find_packages

setup(
    name="goldhold",
    version="0.1.0",
    packages=find_packages(),
    install_requires=["requests>=2.20"],
    python_requires=">=3.8",
    author="All Auto Tunes LLC",
    description="Persistent memory for AI agents.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://goldhold.ai",
    license="Proprietary",
    classifiers=[
        "License :: Other/Proprietary License",
        "Programming Language :: Python :: 3",
    ],
)
